@@ -114,7 +114,7 @@ final class StrictUnifiedDiffOutputBuilderIntegrationTest extends TestCase
         $from = FileUtils::getFileContent($fileFrom);
         $to   = FileUtils::getFileContent($fileTo);
 
-        $diff = (new Differ(new StrictUnifiedDiffOutputBuilder(['fromFile' => 'Original', 'toFile' => 'New'])))->diff($from, $to);
+        $diff = new Differ(new StrictUnifiedDiffOutputBuilder(['fromFile' => 'Original', 'toFile' => 'New']))->diff($from, $to);
 
         if ('' === $diff && $from === $to) {
             // odd case: test after executing as it is more efficient than to read the files and check the contents every time
@@ -132,7 +132,7 @@ final class StrictUnifiedDiffOutputBuilderIntegrationTest extends TestCase
         $from = FileUtils::getFileContent($fileFrom);
         $to   = FileUtils::getFileContent($fileTo);
 
-        $diff = (new Differ(new StrictUnifiedDiffOutputBuilder(['fromFile' => 'Original', 'toFile' => 'New'])))->diff($from, $to);
+        $diff = new Differ(new StrictUnifiedDiffOutputBuilder(['fromFile' => 'Original', 'toFile' => 'New']))->diff($from, $to);
 
         if ('' === $diff && $from === $to) {
             // odd case: test after executing as it is more efficient than to read the files and check the contents every time
@@ -147,7 +147,7 @@ final class StrictUnifiedDiffOutputBuilderIntegrationTest extends TestCase
     #[DataProvider('provideBasicDiffGeneration')]
     #[DataProvider('provideOutputBuildingCases')]
     #[DataProvider('provideSample')]
-    public function testIntegrationOfUnitTestCasesGitApply(string $expected, string $from, string $to): void
+    public function testIntegrationOfUnitTestCasesGitApply(string $expected, string $from, string $to, ?array $options = null): void
     {
         $this->doIntegrationTestGitApply($expected, $from);
     }
@@ -155,7 +155,7 @@ final class StrictUnifiedDiffOutputBuilderIntegrationTest extends TestCase
     #[DataProvider('provideBasicDiffGeneration')]
     #[DataProvider('provideOutputBuildingCases')]
     #[DataProvider('provideSample')]
-    public function testIntegrationOfUnitTestCasesPatch(string $expected, string $from, string $to): void
+    public function testIntegrationOfUnitTestCasesPatch(string $expected, string $from, string $to, ?array $options = null): void
     {
         $this->doIntegrationTestPatch($expected, $from, $to);
     }
