@@ -27,7 +27,7 @@ final class FileUtils
                 sprintf(
                     'Failed to read content of file "%s".%s',
                     $file,
-                    $error ? ' ' . $error['message'] : '',
+                    $error !== null ? ' ' . $error['message'] : '',
                 ),
             );
         }
